@@ -7,5 +7,5 @@ class JsonAble:
         pass
 
     @abstractmethod
-    def from_dict(dic):
+    def from_dict(dic: dict):
         pass
