@@ -89,6 +89,39 @@ class DataLine:
         return self.__data
 
 
+class KeyType:
+    """
+    键类型
+    """
+    # 唯一键
+    UNIQUE = 1
+    # 合并键
+    MERGE = 2
+    # 比较键
+    COMPARE = 3
+    # 自定义类型
+    CUSTOM = 4
+
+
+class KeyDescriptor:
+    def __init__(self, idx: int, key_type: KeyType.COMPARE or KeyType.UNIQUE or KeyType.COMPARE, params):
+        self.__key_index = idx
+        self.__key_type = key_type
+        self.__params = params
+
+    @property
+    def key_index(self):
+        return self.__key_index
+
+    @property
+    def key_type(self):
+        return self.__key_type
+
+    @property
+    def params(self):
+        return self.__params
+
+
 class DefaultParsedData(BaseParsedData):
     """
     分析后的数据，应用本身不处理此数据，由后续插件处理，因此也可以用其它的数据格式表示分析后的数据
@@ -100,7 +133,7 @@ class DefaultParsedData(BaseParsedData):
         self.file_name: str = None
         self.types: List[str] = []
         # 键的描述列表: True: 唯一键, False: 不是任何键, 任何字符串: 合并键标签，具有同样标签的键可以合并
-        self.key_descriptors: List[bool or str] = []
+        self.key_descriptors: List[KeyDescriptor] = []
         self.field_names: List[str] = []
         self.field_comments: List[str] = []
         # 数据行
